@@ -2,31 +2,34 @@
 #define FILTRATION_H
 
 #include "scorer.h"
+#include "vector.h"
 
 struct filename {
 	char *p;
 	int dirlength;
+	int restlen;
 };
 
-char filter_dir_separator;
+extern char filter_dir_separator;
 
-int dont_sort;
+extern int dont_sort;
+extern int ignore_positions;
 
 // vector of struct filter_result
-struct vector filtered;
+extern struct vector filtered;
 
 typedef void (*filter_destructor)(void *);
 typedef int (*filter_func)(struct filename *, const void *, struct filter_result *, unsigned *);
 
 void *prepare_filter(const char *filter, filter_func *func, filter_destructor *destructor);
 
-int compare_filter_result(struct filter_result *a, struct filter_result *b);
-
 void filter_files_sync(char *pattern);
 void filter_files(char *pattern, void (*callback)(char *));
 
 int obtain_match(const char *pattern, int files_index, unsigned *match);
 
+void uninit_filter(void);
+
 #define FILTER_LIMIT 1000
 
 #endif
