@@ -15,7 +15,9 @@
  * along with this program.  If not, see
  * `http://www.gnu.org/licenses/'.
  */
-#define _GNU_SOURCE
+#ifndef NO_CONFIG
+#include "config.h"
+#endif
 
 #include <string.h>
 #include <stdio.h>
@@ -44,6 +46,8 @@ char *eat_prefix;
 int gpicker_bytes_readen;
 int gpicker_load_stdin_too;
 
+int dont_sort_initial;
+
 static volatile
 int reading_aborted;
 
@@ -53,12 +57,13 @@ void init_loading(void)
 }
 
 static
-void add_filename(char *p, int dirlength)
+void add_filename(char *p, int dirlength, int restlen)
 {
 	struct filename *last = vector_append(&files_vector);
 
 	last->p = p;
 	last->dirlength = dirlength;
+	last->restlen = restlen;
 }
 
 #define INIT_BUFSIZE (128*1024)
@@ -122,6 +127,8 @@ void read_filenames(int fd)
 
 	int eat_prefix_len = strlen(eat_prefix);
 
+	timing_t start = start_timing();
+
 	while (p < endp) {
 		int dirlength = 0;
 		char *start;
@@ -129,16 +136,24 @@ void read_filenames(int fd)
 		if (strncmp(eat_prefix, p, eat_prefix_len) == 0)
 			p += eat_prefix_len;
 		start = p;
+#if 1
 		while ((ch = *p++) != name_separator[0])
 			if (ch == filter_dir_separator)
 				dirlength = p - start;
+#else
+		p = rawmemchr(start, name_separator[0]) + 1;
+		char *rp = memrchr(start, filter_dir_separator, p - 1 - start);
+		dirlength = rp ? rp - start : 0;
+#endif
 		p[-1] = 0;
-		add_filename(start, dirlength);
+		add_filename(start, dirlength, p - 1 - start - dirlength);
 	}
 
-	if (!dont_sort)
-		_quicksort_top(files, nfiles, sizeof(struct filename),
+	if (!dont_sort && !dont_sort_initial)
+		_quicksort_top(files, files_vector.used, sizeof(struct filename),
 			       (int (*)(const void *, const void *))filename_compare, files + FILTER_LIMIT);
+
+	finish_timing(start, "filenames parsing");
 }
 
 void read_filenames_abort(void)
@@ -146,6 +161,7 @@ void read_filenames_abort(void)
 	reading_aborted = 1;
 }
 
+#ifndef NO_CONFIG
 static
 void read_all(int fd, char *data, int size)
 {
@@ -228,7 +244,7 @@ void read_filenames_from_mlocate_db(int fd)
 				char *dup = malloc(total_len+1);
 				memcpy(dup, read_buffer, total_len);
 				dup[total_len] = 0;
-				add_filename(dup, dirlength);
+				add_filename(dup, dirlength, total_len - dirlength);
 			}
 
 			p += p_len + 1;
@@ -240,6 +256,7 @@ void read_filenames_from_mlocate_db(int fd)
 	}
 
 	free(data);
+	finish_timing(start, "read_filenames_from_mlocate_db");
 
 	if (gpicker_load_stdin_too) {
 		read_filenames(0);
@@ -247,8 +264,9 @@ void read_filenames_from_mlocate_db(int fd)
 
 	if (!dont_sort) {
 		start = start_timing();
-		_quicksort_top(files, nfiles, sizeof(struct filename),
+		_quicksort_top(files, files_vector.used, sizeof(struct filename),
 			       (int (*)(const void *, const void *))filename_compare, files + FILTER_LIMIT);
 		finish_timing(start, "initial qsort");
 	}
 }
+#endif /* NO_CONFIG */
