@@ -31,6 +31,7 @@
 #include <errno.h>
 #include <assert.h>
 #include <libgen.h>
+#include <sys/wait.h>
 
 #if defined(__APPLE__) && defined(__MACH__)
 
@@ -53,6 +54,7 @@
 #include "inline_qsort.h"
 #include "loading.h"
 #include "do_with_main_loop.h"
+#include "scorer.h"
 
 static GtkWindow *top_window;
 static GtkEntry *name_entry;
@@ -162,7 +164,7 @@ void cell_data_func(GtkTreeViewColumn *col,
 	if (text) {
 		const char *pattern = applied_pattern;
 		int patlen = strlen(pattern);
-		unsigned match[patlen];
+		unsigned match[patlen ? patlen : 1];
 		int passes;
 		int i;
 
@@ -481,6 +483,18 @@ gboolean key_events_delegator(GtkWidget *w, GdkEventKey *e, gpointer dummy)
 	return rv;
 }
 
+static
+gboolean on_move_cursor(GtkTreeView *view, GtkMovementStep step, gint arg2, gpointer user_data)
+{
+	GtkTreeSelection *sel;
+	GtkTreePath *path;
+	sel = gtk_tree_view_get_selection(view);
+	gtk_tree_view_get_cursor(view, &path, NULL);
+	gtk_tree_selection_select_path(sel, path);
+	gtk_tree_path_free(path);
+	return TRUE;
+}
+
 static
 void setup_signals(void)
 {
@@ -490,6 +504,8 @@ void setup_signals(void)
 	g_signal_connect(tree_view, "row-activated", G_CALLBACK(choice_made), 0);
 	g_signal_connect(name_entry, "changed", G_CALLBACK(on_entry_changed), 0);
 
+	g_signal_connect_after(tree_view, "move-cursor", G_CALLBACK(on_move_cursor), 0);
+
 	g_object_set(G_OBJECT(tree_view), "can-focus", FALSE, NULL);
 	g_signal_connect_after(name_entry, "key-press-event", G_CALLBACK(key_events_delegator), 0);
 	g_signal_connect_after(name_entry, "key-release-event", G_CALLBACK(key_events_delegator), 0);
@@ -731,6 +747,7 @@ int simple_main(int, char **);
 int main(int argc, char **argv)
 {
 	init_loading();
+	prepare_scorer();
 
 	char *gpicker = basename(xstrdup(argv[0]));
 	if (!strcmp(gpicker, "gpicker-simple"))
@@ -738,7 +755,6 @@ int main(int argc, char **argv)
 
 	timing_t tstart = start_timing();
 
-	g_thread_init(0);
 	parse_options(argc, argv); /* inits GTK+ too */
 
 	atexit(kill_child_pid);
